"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var graphql_1 = require("graphql");
var transform_fragment_document_1 = require("./transform-fragment-document");
var transform_operation_1 = require("./transform-operation");
var debugging_1 = require("../debugging");
var logger_1 = require("../utils/logger");
function transformDocument(schema, documentNode) {
    var result = {
        fragments: [],
        operations: [],
        hasFragments: false,
        hasOperations: false
    };
    var definitions = documentNode.definitions || [];
    debugging_1.debugLog("[transformDocument] transforming total of " + definitions.length + " definitions...");
    definitions.forEach(function (definitionNode) {
        if (definitionNode.kind === graphql_1.Kind.OPERATION_DEFINITION) {
            result.operations.push(transform_operation_1.transformOperation(schema, definitionNode));
        }
        else if (definitionNode.kind === graphql_1.Kind.FRAGMENT_DEFINITION) {
            result.fragments.push(transform_fragment_document_1.transformFragment(schema, definitionNode));
        }
        else {
            logger_1.logger.warn("It seems like you provided an invalid GraphQL document: ");
            logger_1.logger.warn(definitionNode);
        }
    });
    result.hasFragments = result.fragments.length > 0;
    result.hasOperations = result.operations.length > 0;
    return result;
}
exports.transformDocument = transformDocument;
//# sourceMappingURL=transform-document.js.map